import { storeToRefs } from "pinia";
import { useCartStore } from "src/stores/cart";
import { useModalStore } from "src/stores/modalStore";
import { watch } from "vue";
import { useRoute } from "vue-router";
import { usePostalCalendar } from "./usePostalCalendar";

export function useProductPage() {
  const route = useRoute();

  const {
    fields: { dedication, dedicationAttrs },
  } = usePostalCalendar({ modalItem: "isOpenAvailability" });

  const modalStore = useModalStore();
  const { openModal } = modalStore;

  const cartStore = useCartStore();
  const { getProduct, getProducts } = cartStore;
  const { products, featuredProducts, addCartLoadingBtn } =
    storeToRefs(cartStore);

  watch(
    () => products.value.current?.type,
    (newCategory) => {
      getProducts({
        // type: newCategory,
      });
    }
  );

  watch(
    () => route.params.id,
    (newId) => {
      getProduct(newId);
    }
  );

  const checkImageValidity = (imageLink) => {
    const validExtensions = [".jpg", ".jpeg", ".png"];

    if (imageLink) {
      const extension = imageLink.substring(imageLink.lastIndexOf("."));
      return validExtensions.includes(extension.toLowerCase());
    }

    return true;
  };

  return { checkImageValidity, openModal }
}
